
<!-- markdownlint-disable MD046 -->

# Installation

## Using `pip`

You can `pip install` different versions of this project as usual:

```sh
pip install torch-crps
```


## Any Version from GitHub

You can install any version directly from GitHub:

```sh
GIT_REF=main # or some other ref, e.g. a branch or tag
pip install git+https://github.com/famura/torch-crps@${GIT_REF}
```
